===================
django-geopostcodes
===================

|Build Status|_ |Docs Status|_ |Coverage Status|_ |Code Status|_

.. |Build Status| image:: https://travis-ci.org/alexhayes/django-geopostcodes.png?branch=master
.. _Build Status: https://travis-ci.org/alexhayes/django-geopostcodes
.. |Docs Status| image:: https://readthedocs.org/projects/django-geopostcodes/badge/?version=latest
.. _Docs Status: http://django-geopostcodes.readthedocs.org/en/latest/index.html
.. |Coverage Status| image:: https://codecov.io/gh/alexhayes/django-geopostcodes/badge.svg
.. _Coverage Status: https://codecov.io/gh/alexhayes/django-geopostcodes
.. |Code Status| image:: https://landscape.io/github/alexhayes/django-geopostcodes/master/landscape.png
.. _Code Status: https://landscape.io/github/alexhayes/django-geopostcodes/

Django modelling for `geopostcodes.com`_

NOTE: This repository does not include the actual data, you must purchase this
from `geopostcodes.com`_ and then import it, as per the documentation
at `django-geopostcodes.readthedocs.org`_

``django-geopostcodes`` supports Python 2.7, 3.3, 3.4 and pypy for Django 1.7 and 1.8.

Docs
====

Available at `django-geopostcodes.readthedocs.org`_


License
=======

This software is licensed under the `MIT License`. See the LICENSE_
file in the top distribution directory for the full license text.


Author
======

Alex Hayes <alex@alution.com>

.. _Django: https://www.djangoproject.com/
.. _Models: https://docs.djangoproject.com/en/stable/topics/db/models/
.. _django-geopostcodes.readthedocs.org: http://django-geopostcodes.readthedocs.org/en/latest/
.. _LICENSE: https://github.com/alexhayes/django-geopostcodes/blob/master/LICENSE
.. _geopostcodes.com: http://www.geopostcodes.com
